/*
    Copyright 2020-2021. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

package com.huawei.hms.flutter.safetydetect.util;

import java.util.ArrayList;

import io.flutter.plugin.common.MethodCall;

public final class PlatformUtil {
    private PlatformUtil() {
    }

    public static byte[] getByteArrayArg(final MethodCall methodCall, String key) {
        if (methodCall.argument(key) instanceof byte[]) {
            return (byte[]) methodCall.argument(key);
        }
        return new byte[0];
    }

    public static String getStringArg(final MethodCall methodCall, String key) {
        return methodCall.argument(key);
    }

    public static int[] getThreatTypes(final MethodCall methodCall) {
        ArrayList<Integer> threatTypesList = methodCall.argument("threatTypes");
        if (threatTypesList != null) {
            int arraySize = threatTypesList.size();
            int[] threatTypes = new int[arraySize];
            for (int i = 0; i < arraySize; i++) {
                threatTypes[i] = threatTypesList.get(i);
            }
            return threatTypes;
        }
        return new int[0];
    }
}
